# AUTOGENERATED! DO NOT EDIT! File to edit: dynamodb.ipynb (unless otherwise specified).

__all__ = []

# Cell
#export
from dataclasses import field
from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, Undefined