# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"S3Event": "S3.ipynb",
         "Response": "apigateway.ipynb",
         "Event": "apigateway.ipynb",
         "Product": "apigateway.ipynb",
         "Products": "apigateway.ipynb"}

modules = ["S3.py",
           "apigateway.py",
           "dynamodb.py"]

doc_url = "https://thanakijwanavit.github.io/awsSchema/"

git_url = "https://github.com/thanakijwanavit/awsSchema/tree/master/"

def custom_doc_links(name): return None
